;  speedy-config.inc - definitions for config ROM
;
;  Copyright (c) 2014-2015 by Matthias Reichl <hias@horus.com>
;
;  This program is free software; you can redistribute it and/or modify
;  it under the terms of the GNU General Public License as published by
;  the Free Software Foundation; either version 2 of the License, or
;  (at your option) any later version.
;
;  This program is distributed in the hope that it will be useful,
;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;  GNU General Public License for more details.
;
;  You should have received a copy of the GNU General Public License
;  along with this program; if not, write to the Free Software
;  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
;

; RAM bank used for storing selected config
; note: the end of this RAM block also contains the 6810 area(s)
; in the last 512 bytes, don't ever use these!
CONFIG_RAM_BANK	= $3A

CONFIG_RAM_ADDRESS	= XRAM_BASE+$1D00

; switch position
CONFIG_RAM_ADR_SW	= CONFIG_RAM_ADDRESS+$00
; rom bank
CONFIG_RAM_ADR_BANK	= CONFIG_RAM_ADDRESS+$01
; mode
CONFIG_RAM_ADR_MODE	= CONFIG_RAM_ADDRESS+$02
; checksum
CONFIG_RAM_ADR_CS	= CONFIG_RAM_ADDRESS+$03
; checksum EOR $FF
CONFIG_RAM_ADR_CSE	= CONFIG_RAM_ADDRESS+$04

; total length of config block
CONFIG_RAM_ADDRESS_LEN	= $05

; save bank+mode to config RAM
	.macro SAVE_CONFIG_RAM ; bank, mode
	.if %0 <> 2
	.error "SAVE_CONFIG_RAM needs 2 parameters"
	.endif
; don't save config when using RAM mode or selecting config mode
	LDA %1
	BMI SKIP_SAVE_CONFIG
	CMP #BLOCK_BASE_CONFIG
	BEQ SKIP_SAVE_CONFIG

	LDA #CONFIG_RAM_BANK
	STA RAMBANK
	LDA %1
	STA CONFIG_RAM_ADR_BANK		; ram/rom bank
	LDA %2
	STA CONFIG_RAM_ADR_MODE		; mode
	LDA CFG_MODE_IN
	LSR
	LSR
	LSR
	AND #3
	STA CONFIG_RAM_ADR_SW		; save switch position
	CLC
	ADC CONFIG_RAM_ADR_BANK
	ADC CONFIG_RAM_ADR_MODE
	ADC #0
	STA CONFIG_RAM_ADR_CS
	EOR #$FF
	STA CONFIG_RAM_ADR_CSE
	LDA #0
	STA RAMBANK

SKIP_SAVE_CONFIG
	.endm

; try to read bank+mode from config RAM, then clear it
; if successfull, C is cleared and the config is copied
	.macro READ_CONFIG_RAM ; bank, mode
	.if %0 <> 2
	.error "READ_CONFIG_RAM needs 2 parameters"
	.endif
	LDA #CONFIG_RAM_BANK
	STA RAMBANK
; verify checksum
	CLC
	LDA CONFIG_RAM_ADR_SW
	ADC CONFIG_RAM_ADR_BANK
	ADC CONFIG_RAM_ADR_MODE
	ADC #0
	CMP CONFIG_RAM_ADR_CS
	BNE READ_CONFIG_RAM_ERR
	EOR #$FF
	CMP CONFIG_RAM_ADR_CSE
	BNE READ_CONFIG_RAM_ERR

; check if mode select switch is the same as before
	LDA CFG_MODE_IN
	LSR
	LSR
	LSR
	AND #3
	CMP CONFIG_RAM_ADR_SW
	BNE READ_CONFIG_RAM_ERR

; checksum is correct, switch position identical, copy config
	LDA CONFIG_RAM_ADR_BANK
	STA %1
	LDA CONFIG_RAM_ADR_MODE
	STA %2

	CLC
	BCC READ_CONFIG_RAM_END
READ_CONFIG_RAM_ERR
	SEC
READ_CONFIG_RAM_END
	.endm

; invalidate the config RAM
	.macro CLEAR_CONFIG_RAM
	LDA #$A5
	STA CONFIG_RAM_ADR_SW
	STA CONFIG_RAM_ADR_CSE
	LDA #0
	STA CONFIG_RAM_ADR_BANK
	STA CONFIG_RAM_ADR_MODE
	STA CONFIG_RAM_ADR_CS
	.endm
